@@ -20,7 +20,9 @@ tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR)
 # PhaseNet_model_path = os.path.join(PhaseNet_core_path,"model","190703-214543")
 
 class EQTransformerObj(object):
-    def __init__(self,eqt_path,
+    def __init__(self,
+                eqt_path,
+                model_path=None,
                 n_processor=2,overlap=0.3,
                 detection_threshold=0.1, P_threshold=0.1,
                 S_threshold=0.1,number_of_plots=1,
@@ -34,7 +36,10 @@ class EQTransformerObj(object):
         EQTransformer parameters
         """
         self.eqt_path = eqt_path
-        self.model_path = os.path.join(eqt_path,"ModelsAndSampleData","EqT_model.h5")
+        if model_path == None:
+            self.model_path = os.path.join(eqt_path,"ModelsAndSampleData","EqT_model.h5")
+        else:
+            self.model_path = model_path
         self.n_processor = n_processor
         self.overlap = overlap
         self.detection_threshold = detection_threshold
@@ -48,8 +53,9 @@ class EQTransformerObj(object):
         self.name = "EQTransformer"
 
 class PhaseNetObj(object):
-    def __init__(self, phasenet_path,
-                 mode='pred', P_threshold=0.3, S_threshold=0.3,
+    def __init__(self, pnet_path,
+                modeldir_path=None,
+                mode='pred', P_threshold=0.3, S_threshold=0.3,
                 batch_size=2, plot = False, save_result=False,
                 epochs = 100,learning_rate= 0.01,decay_step = -1,
                 decay_rate = 0.9,momentum = 0.9,filters_root = 8,
@@ -70,8 +76,11 @@ class PhaseNetObj(object):
         PhaseNet parameters
         """
 
-        self.phasenet_path = phasenet_path
-        self.model_dir = os.path.join(phasenet_path,"model","190703-214543")
+        self.phasenet_path = pnet_path
+        if modeldir_path == None:
+            self.model_dir = os.path.join(pnet_path,"model","190703-214543")
+        else:
+            self.model_dir = modeldir_path
         self.mode = mode
         self.tp_prob = P_threshold
         self.ts_prob = S_threshold
