@@ -25,6 +25,7 @@ import os
 import csv
 import sys
 import json
+import math
 import time
 import obspy
 import shutil
@@ -38,12 +39,12 @@ from datetime import timedelta
 from SeisMonitor.utils import printlog,isfile
 from SeisMonitor.monitor.downloader.utils import get_chunktimes
 import concurrent.futures as cf
+from git import Repo
 from obspy.core.event.origin import Pick
 from obspy.core.event.base import (QuantityError,
                                 WaveformStreamID,
                                 CreationInfo,
                                 Comment)
-from git import Repo
 from obspy.core.event import ResourceIdentifier
 
 
@@ -65,7 +66,7 @@ def git_clone_aipicker(name,repo_dir):
 
     repo_dir = os.path.join(repo_dir,name)
     if os.path.isdir(repo_dir):
-        print("There is alaready")
+        print("There is already")
         return True
     else:
         Repo.clone_from(git_url, repo_dir)
@@ -204,8 +205,8 @@ def get_filenames(mseed, filter_net=[],
     return filenames
 
 def mv_mseed2onefolder(mseed_folder,one_folder):
-    print("aca",mseed_folder)
-    print("aca",one_folder)
+    # print("aca",mseed_folder)
+    # print("aca",one_folder)
     for dp, dn, filenames in os.walk(mseed_folder):
         for f in filenames:
             if f.endswith(".mseed") :
@@ -434,7 +435,7 @@ def rm_phasenet_duplicate_picks(path,output_path):
                 logger.debug(f'Overlap:{overlap_prob_avg} > Single:{single_prob_avg} | Overlap selected')
                 return df_overlap
     
-    df = pd.read_csv(path)
+    df = pd.read_csv(path,dtype={"location":str})
     if df.empty == True:
         return df
 
@@ -495,16 +496,25 @@ def picks2df(picks):
         seismonitor["phasehint"] = pick.phase_hint 
         seismonitor["network"] = pick.waveform_id.network_code
         seismonitor["station"] = pick.waveform_id.station_code
-        seismonitor["location"] = pick.waveform_id.location_code
         seismonitor["instrument_type"] = pick.waveform_id.channel_code[0:2]
         seismonitor["author"] = pick.method_id.id
         seismonitor["creation_time"] = pick.creation_info.creation_time.strftime("%Y-%m-%d %H:%M:%S.%f")
+        
+        if isinstance(pick.waveform_id.location_code,int):
+            if math.isnan(pick.waveform_id.location_code):
+                seismonitor["location"] = ""
+        elif pick.waveform_id.location_code == None:
+            seismonitor["location"] = ""
+        else:
+            seismonitor["location"] = "{:02d}".format(int(pick.waveform_id.location_code))
 
         for key,val in pick.comments[0].items():
             seismonitor[key] = val
 
         df.append(seismonitor)
     df = pd.DataFrame(df)
+    df["location"] = df["location"].astype(str)
+    # print(df["location"])
     date_cols = ["arrival_time","creation_time",
                 "event_start_time","event_end_time",
                 "mseed_start_time","mseed_end_time"]
@@ -621,7 +631,7 @@ def pick_constructor(datalist,picks, prob, wf_name, ph_type, min_prob,
         raise Exception("No datalist ")
 
     else:
-        datalist = pd.read_csv(datalist)
+        datalist = pd.read_csv(datalist,dtype={"location":str})
         datalist[['mseed_start_time','mseed_end_time']] = datalist[['mseed_start_time','mseed_end_time']].apply(pd.to_datetime)
         datalist = datalist.set_index("fname")
 
@@ -648,6 +658,7 @@ def pick_constructor(datalist,picks, prob, wf_name, ph_type, min_prob,
                 net = row["network"]
                 sta = row["station"]
                 loc = row["location"]
+                # print(loc,type(loc))
                 ch = row["instrument_type"]
                 
                 if one_single_sampling_rate == -1:
